# CraftBeerPi4 TwoKettleLogic Plugin

## Two Kettle Logic ##
Plugin will provide the ability to apply temp control to two kettles in the same step. This can be useful if you're using the boil kettle to heat strike water and get the hot liquor tank up to temp all in the same step.

## Installation: ##
* sudo pip3 install cbpi4-TwoKettleLogic
* or install from repo: sudo pip3 install https://github.com/sjhoglund/cbpi4-TwoKettleLogic/archive/main.zip
* cbpi add cbpi4-TwoKettleLogic

## Usage: ##
More to come

## Changelog: ##
* 01-29-22: (0.0.1) Updated README